pub struct Node<'g> { /* private fields */ }Expand description
A node in the graph.
This is used to iterates throught the nodes of a graph.
Implementations
Sourceimpl<'g> Node<'g>
impl<'g> Node<'g>
Sourcepub fn neighbors(&self) -> &IndexSet<usize>
pub fn neighbors(&self) -> &IndexSet<usize>
Returns the set of labels of the neighbors of the node.
Sourcepub fn degree(&self) -> usize
pub fn degree(&self) -> usize
Returns the degree of the node. That is, the number of neighbors.
Sourcepub fn has_neighbor(&self, label: usize) -> bool
pub fn has_neighbor(&self, label: usize) -> bool
Checks if a node a neighbor with the given label
Sourcepub fn is_variable(&self) -> bool
pub fn is_variable(&self) -> bool
Checks if a node is a variable.
Sourcepub fn is_constraint(&self) -> bool
pub fn is_constraint(&self) -> bool
Checks if a node is a constraint.